Clojure only.

capra.http.error

Functions for handling client or server errors.

Functions for handling client or server errors.
raw docstring

error-handlersclj

A map of plaintext error handlers for responding to bad requests

A map of plaintext error handlers for responding to bad requests
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries